@@ -83,7 +83,7 @@ class Transaction(object):
         return request.response.banks
 
     @staticmethod
-    def get_service(payment_method_id: int):
+    def get_service(payment_method_id: int=None):
         """
         Get a transaction getservice :class:`paynlsdk.api.transaction.getservice.Response` instance
 
