@@ -430,10 +430,12 @@ class ServiceSchema(Schema):
 
     @pre_load
     def pre_process(self, data):
-        if ParamValidator.is_empty(data['errorUrl']):
-            del data['errorUrl']
-        if ParamValidator.is_empty(data['successUrl']):
-            del data['successUrl']
+        if 'errorUrl' in data:
+            if ParamValidator.is_empty(data['errorUrl']):
+                del data['errorUrl']
+        if 'successUrl' in data:
+            if ParamValidator.is_empty(data['successUrl']):
+                del data['successUrl']
         return data
 
     @post_load
@@ -1580,12 +1582,55 @@ class BankDetailsSchema(Schema):
         return BankDetails(**data)
 
 
+class Brand(object):
+    """
+    Brand details structure
+    """
+    def __init__(self,
+                 id: int=None,
+                 name: str=None,
+                 image: str=None,
+                 public_description: str=None
+                 ):
+        """
+        Create brand details instance
+
+        :param id: Brand ID
+        :type id: int
+        :param name: Brand name
+        :type name: str
+        :param image: Brand image
+        :type image: str
+        :param public_description: Public description
+        :type public_description: str
+        """
+        self.id = id
+        self.name = name
+        self.image = image
+        self.public_description = public_description
+
+    def __repr__(self):
+        return self.__dict__.__str__()
+
+
+class BrandSchema(Schema):
+    id = fields.Integer(required=True)
+    name = fields.String(required=True)
+    image = fields.String(required=False, allow_none=True)
+    public_description = fields.String(required=False, allow_none=True)
+
+    @post_load
+    def create_brand(self, data):
+        return Brand(**data)
+
+
 class PaymentOptionBase(object):
     """
     Payment option base details structure
     """
     def __init__(self, id: int=None, name: str=None, visible_name: str=None,
-                 img: str=None, path: str=None, state: int=None):
+                 img: str=None, path: str=None, state: int=None, min_amount: int=None,
+                 max_amount: int=None, brand: Brand=None):
         """
         Create Payment option details instance
 
@@ -1604,6 +1649,12 @@ class PaymentOptionBase(object):
         :type path: str
         :param state: option status (0: unavailable, 1: available)
         :type state: int
+        :param min_amount: minimum amount
+        :type min_amount: int
+        :param max_amount: maximum amount
+        :type max_amount: int
+        :param brand: brand object
+        :type brand: Brand
         """
         self.id = id
         self.name = name
@@ -1611,6 +1662,9 @@ class PaymentOptionBase(object):
         self.img = img
         self.path = path
         self.state = state ## TODO: Enum Availability
+        self.min_amount = min_amount
+        self.max_amount = max_amount
+        self.brand = brand
 
     def __repr__(self):
         return str(self.__dict__)
@@ -1642,9 +1696,20 @@ class PaymentSubOptionSchema(Schema):
     id = fields.Integer(required=True)
     name = fields.String(required=True)
     visible_name = fields.String(required=True, load_from='visibleName')
-    img = fields.String(required=True)
-    path = fields.String(required=True)
+    img = fields.String(required=False)
+    path = fields.String(required=False)
     state = fields.Integer(required=True)
+    min_amount = fields.Integer(required=False, allow_none=True)
+    max_amount = fields.Integer(required=False, allow_none=True)
+    #state = fields.Integer(required=False)
+
+    @pre_load
+    def postprocess(self, data):
+        # Because img and image really is the same... SIGH
+        if 'image' in data:
+            data['img'] = data['image']
+            del data['image']
+        return data
 
     @post_load
     def create_payment_sub_option(self, data):
@@ -1689,13 +1754,16 @@ class PaymentOptionSchema(Schema):
     id = fields.Integer(required=True)
     name = fields.String(required=True)
     visible_name = fields.String(required=True, load_from='visibleName')
-    img = fields.String(required=True)
-    path = fields.String(required=True)
+    img = fields.String(required=False)
+    path = fields.String(required=False)
     state = fields.Integer(required=True)
+    min_amount = fields.Integer(required=False, allow_none=True)
+    max_amount = fields.Integer(required=False, allow_none=True)
     use_only_in_store = fields.Boolean(required=False, allow_none=True, load_from='useOnlyInStore')
     payment_method_id = fields.Integer(allow_None=True, required=False, load_from='paymentMethodId')
     payment_sub_options = fields.List(fields.Nested(PaymentSubOptionSchema), required=False, allow_none=True,
                                       load_from='paymentOptionSubList')
+    brand = fields.Nested(BrandSchema, required=False, allow_none=True)
 
     @pre_load
     def postprocess(self, data):
@@ -1708,6 +1776,10 @@ class PaymentOptionSchema(Schema):
             for i, item in data['paymentOptionSubList'].items():
                 list.append(item)
             data['paymentOptionSubList'] = list
+        # Because img and image really is the same... SIGH
+        if 'image' in data:
+            data['img'] = data['image']
+            del data['image']
         return data
 
     @post_load
@@ -1767,7 +1839,7 @@ class CountryOptionSchema(Schema):
     visible_name = fields.String(required=True, load_from='visibleName')
     in_eu = fields.Boolean(required=True)
     img = fields.String(required=True)
-    path = fields.String(required=True)
+    path = fields.String(required=False, allow_none=True)
     # UGH! Source is dictionary based nested?? Marshmallow/Python does not process this well!
     payment_option_list = fields.List(fields.Nested(PaymentOptionSchema), allow_none=True, load_from='paymentOptionList')
 
